<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Form Recipients /////////////////////////
// Buttons:
define('FORM_RECIPIENTS_HEADING', "Uredi oblika Prejemniki");
define('FORM_RECIPIENTS_EDIT_FORM_RECIPIENTS_BTN', "Uredi oblika Prejemniki");
// Console Text:
define('FORM_RECIPIENTS_FORM_PAGE', "obrazec Page");
define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "lahko nastavite več kot enega prejemnika z ločitvijo e-pošto z vejicami.");
// Popup Messages:
define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "Shranjevanje prejemnika ...");
define('VIEW_FORM_TABLES_HEADING', "Ogled tabele obrazcev");
define('VIEW_FORM_TABLES_BTN', "Ogled tabele obrazcev");
define('VIEW_FORM_TABLES_SELECT_TABLE', "Izberite tabele za ogled");
define('VIEW_FORM_TABLES_FILTER_READ', "Filtriraj branje sporočil");
?>